PublicKey

Enum PublicKey 

#[repr(u8)]
pub enum PublicKey { X25519(PublicKey), P256(PublicKey), MlKem512(MlKemPublicKey<libcrux_ml_kem::::mlkem512::MlKem512PublicKey::{constant#0}>), MlKem768(MlKemPublicKey<libcrux_ml_kem::::mlkem768::MlKem768PublicKey::{constant#0}>), X25519MlKem768Draft00(X25519MlKem768Draft00PublicKey), XWingKemDraft06(XWingKemDraft06PublicKey), MlKem1024(MlKemPublicKey<libcrux_ml_kem::::mlkem1024::MlKem1024PublicKey::{constant#0}>), }
A KEM public key.

Variants



X25519(PublicKey)



P256(PublicKey)



MlKem512(MlKemPublicKey<libcrux_ml_kem::::mlkem512::MlKem512PublicKey::{constant#0}>)



MlKem768(MlKemPublicKey<libcrux_ml_kem::::mlkem768::MlKem768PublicKey::{constant#0}>)



X25519MlKem768Draft00(X25519MlKem768Draft00PublicKey)



XWingKemDraft06(XWingKemDraft06PublicKey)



MlKem1024(MlKemPublicKey<libcrux_ml_kem::::mlkem1024::MlKem1024PublicKey::{constant#0}>)

Implementations

Source

impl PublicKey

pub fn encapsulate(&self, rng: &mut impl CryptoRng) -> Result<(Ss, Ct), Error>

Encapsulate a shared secret to the provided pk and return the (Key, Enc) tuple.

pub fn encapsulate_derand(&self, seed: &[u8]) -> Result<(Ss, Ct), Error>

Encapsulate a shared secret to the provided pk and return the (Key, Enc) tuple.

pub fn encode(&self) -> Vec<u8>

Encode public key.

pub fn decode(alg: Algorithm, bytes: &[u8]) -> Result<PublicKey, Error>

Decode a public key.